@@ -8,12 +8,10 @@ use std::sync::atomic::{AtomicPtr, Ordering};
 use std::sync::{Arc, LockResult};
 use std::time::Duration;
 use std::marker::PhantomData;
-
 use std::collections::{BTreeMap as Map, btree_map::IntoIter as IntoIter, btree_map::Iter as MapIter, btree_map::IterMut as MapIterMut, HashMap};
 use serde::{Deserializer, Serialize, Serializer};
 use serde::ser::SerializeMap;
 
-
 use tokio::sync::{Mutex, MutexGuard};
 
 pub type SyncBtreeMap<K, V> = SyncMapImpl<K, V>;
@@ -67,7 +65,7 @@ unsafe impl<K: Eq + Hash + Clone + Ord, V> Send for SyncMapImpl<K, V> {}
 /// this is safety, dirty mutex ensure
 unsafe impl<K: Eq + Hash + Clone + Ord, V> Sync for SyncMapImpl<K, V> {}
 
-//TODO maybe K will use transmute_copy replace Clone?
+
 impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Hash + Clone {
     pub fn new_arc() -> Arc<Self> {
         Arc::new(Self::new())
@@ -86,7 +84,7 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
 
 
     pub async fn insert(&self, k: K, v: V) -> Option<V> where K: Clone + std::cmp::Ord {
-        let mut m= self.dirty.lock().await;
+        let mut m = self.dirty.lock().await;
         let op = m.insert(k.clone(), v);
         match op {
             None => {
@@ -103,7 +101,7 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
     }
 
     pub fn insert_mut(&mut self, k: K, v: V) -> Option<V> where K: Clone + std::cmp::Ord {
-        let mut m= self.dirty.get_mut();
+        let mut m = self.dirty.get_mut();
         let op = m.insert(k.clone(), v);
         match op {
             None => {
@@ -120,7 +118,7 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
     }
 
     pub async fn remove(&self, k: &K) -> Option<V> where K: Clone + std::cmp::Ord {
-        let mut m= self.dirty.lock().await;
+        let mut m = self.dirty.lock().await;
         let op = m.remove(k);
         match op {
             Some(v) => {
@@ -142,7 +140,7 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
     }
 
     pub fn remove_mut(&mut self, k: &K) -> Option<V> where K: Clone + std::cmp::Ord {
-        let mut m= self.dirty.get_mut();
+        let mut m = self.dirty.get_mut();
         let op = m.remove(k);
         match op {
             Some(v) => {
@@ -176,7 +174,24 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
     }
 
     pub async fn clear(&self) where K: std::cmp::Eq + Hash + Clone + std::cmp::Ord {
-        let mut m= self.dirty.lock().await;
+        let mut m = self.dirty.lock().await;
+        m.clear();
+        unsafe {
+            let k = (&mut *self.read.get()).keys().clone();
+            for x in k {
+                let v = (&mut *self.read.get()).remove(x);
+                match v {
+                    None => {}
+                    Some(v) => {
+                        std::mem::forget(v);
+                    }
+                }
+            }
+        }
+    }
+
+    pub fn clear_mut(&mut self) where K: std::cmp::Eq + Hash + Clone + std::cmp::Ord {
+        let mut m = self.dirty.get_mut();
         m.clear();
         unsafe {
             let k = (&mut *self.read.get()).keys().clone();
@@ -194,9 +209,11 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
 
     pub fn shrink_to_fit(&self) {}
 
+    pub fn shrink_to_fit_mut(&mut self) {}
+
     pub fn from(map: HashMap<K, V>) -> Self where K: Clone + Eq + Hash + std::cmp::Ord {
         let mut s = Self::new();
-        let mut m=s.dirty.get_mut();
+        let mut m = s.dirty.get_mut();
         *m = map;
         unsafe {
             for (k, v) in m.iter() {
@@ -219,9 +236,9 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
     /// # Examples
     ///
     /// ```
-    /// use dark_std::sync::{SyncHashMap};
+    /// use dark_std::sync::{SyncBtreeMap};
     ///
-    /// let mut  map = SyncHashMap::new();
+    /// let mut map = SyncBtreeMap::new();
     /// map.insert_mut(1, "a");
     /// assert_eq!(*map.get(&1).unwrap(), "a");
     /// assert_eq!(map.get(&2).is_none(), true);
@@ -265,7 +282,7 @@ impl<K: Eq + Hash + Clone + Ord, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Ha
     }
 
     pub async fn iter_mut(&self) -> IterMut<'_, K, V> {
-        let mut m= self.dirty.lock().await;
+        let mut m = self.dirty.lock().await;
         let mut iter = IterMut {
             g: m,
             inner: None,
