@@ -62,7 +62,7 @@ unsafe impl<K: Eq + Hash + Clone, V> Send for SyncMapImpl<K, V> {}
 /// this is safety, dirty mutex ensure
 unsafe impl<K: Eq + Hash + Clone, V> Sync for SyncMapImpl<K, V> {}
 
-//TODO maybe K will use transmute_copy replace Clone?
+
 impl<K, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Hash + Clone {
     pub fn new_arc() -> Arc<Self> {
         Arc::new(Self::new())
@@ -191,6 +191,23 @@ impl<K, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Hash + Clone {
         }
     }
 
+    pub fn clear_mut(&mut self) {
+        let mut m = self.dirty.get_mut();
+        m.clear();
+        unsafe {
+            let k = (&mut *self.read.get()).keys().clone();
+            for x in k {
+                let v = (&mut *self.read.get()).remove(x);
+                match v {
+                    None => {}
+                    Some(v) => {
+                        std::mem::forget(v);
+                    }
+                }
+            }
+        }
+    }
+
     pub async fn shrink_to_fit(&self) {
         let mut m = self.dirty.lock().await;
         unsafe {
@@ -199,6 +216,14 @@ impl<K, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Hash + Clone {
         m.shrink_to_fit()
     }
 
+    pub async fn shrink_to_fit_mut(&mut self) {
+        let mut m = self.dirty.get_mut();
+        unsafe {
+            (&mut *self.read.get()).shrink_to_fit()
+        }
+        m.shrink_to_fit()
+    }
+
     pub fn from(map: Map<K, V>) -> Self where K: Clone + Eq + Hash {
         let mut s = Self::with_capacity(map.capacity());
         let mut m = s.dirty.get_mut();
